.grid {
    display: grid;
    grid-template-columns: repeat(auto-fill, minmax(14rem, 1fr));
    grid-gap: 10px;
    width: 90%;
    margin-left: auto;
    margin-right: auto;
    margin-top: 2.5%;
}

.event-content {
    height: 100%;
    width: 100%;
    padding: 0;
}

.event-icon {
    max-height: 2.5rem;
    padding: 0;
    margin: -1.5rem;
    vertical-align: middle;
}

@media all and (max-width: 1024px) {
    * {
        font-size: 22px;
    }
}

